% t_readme.m
% 21/Jul/00
%
%
%                    Tidal Analysis Toolbox
%
% The tidal analysis toolbox uses harmonic analysis to estimate tidal
% consitutents and their uncertainities in scalar and vector time series. 
%
% This package is based on a FORTRAN package developed by M. G.
% G. Foreman and coworkers at the Institute of Ocean Sciences (IOS). (The
% IOS tidal package and user manuals are available from Foreman at
% http://www.ios.bc.ca/ios/iap/pages/tidpack.htm.). S. Lentz and 
% B. Beardsley (WHOI) began translating the code into matlab, 
% and improved the error estimation using matlab spectrum code. 
% R. Pawlowicz (UBC) then completely rewrote it using complex (rather 
% than real) math, adding inference, a user interface, and lots of other 
% goodies. However, the error analysis didn't make it through. There *is*
% a very preliminary error analysis in here. You can check out how well
% it works using the t_synth code.
%
% Caveats: - Presently the nodal corrections are done in such a way that they
% may not be too accurate for time series longer than a year or so (corrections
% are based on the middle time of the input series). If you really have 
% such a time series I'm assuming you know more about harmonic analysis than 
% I do so please modify the code. Tidal predictions are also based on nodal
% corrections at the center time.
%
%          - Shallow water constituents are not used automatically. They can
% be used but you must specify them manually using 'shallow' input option
% to T_TIDE (you can get the names and frequencies of shallow water
% constituents from the CONST structure returned by T_GETCONSTS).
% 
% The toolbox presently contains the following mfiles:
%
% t_tide.m       - computes the tidal analysis of the real or complex 
%                  time series.
%
% t_predic.m     - computes a tidal prediction using the results of t_tide.
%
% t_vuf.m        - computes nodal corrections and astronomical arguments.
%
% t_equilib.m    - computes the equilibrium amplitudes of main constituents
%                  at a given latitude.
%
% t_getconst.m   - loads constituent data of all kinds (based on the data file
%                  from the fortran package)
%
% t_readme.m     - this file.
%
% t_synth.m     - synthesizes noisy data to test real as opposed to
%                 estimated uncertainties (crufty code).
%
% t_demo.m    - a short example using the Tuktoyuktok elevation data.
%
% Various data files are also included:
%
% tide3.dat      - standard constituent data file from the IOS analysis package.
%                  (read once and then results stored in various data structures
%                   in t_constituents.mat)
% t_equilib.dat  - Equilibrium amplitude A and B factors (read once and then 
%                  stored in t_constituents.mat)
%
% t_constituents.mat - constituent data structures
%
% t_example.mat - Sample Tuktoyuktuk elevation data set used as an example in
%                  PMSR-77/10
% 
%
% Questions or comments to:
% R. Pawlowicz (rich@ocgy.ubc.ca) 21/Jul/00

